ignoreBottomInset property

bool ignoreBottomInset
final

Whether the bottom bar should be visible when the bottom of MediaQueryData.viewInsets is increased by system UI elements, such as the onscreen keyboard.

If ignoreBottomInset is true, the bottom bar will move up along with the SheetContentScaffold.body when the bottom value of MediaQueryData.viewInsets increases due to system UI elements, such as the on-screen keyboard.

If false, the bottom bar will be partially or entirely hidden, depending on the bottom value of MediaQueryData.viewInsets. For example, if the bottom value of MediaQueryData.viewInsets is half the height of the bottom bar, only half of the bottom bar will remain visible. The default value is false.

Even if this property is true, the bottom bar may be hidden depending on the BottomBarVisibility type. For example, when using ConditionalBottomBarVisibility, the bottom bar is always hidden if the ConditionalBottomBarVisibility.isVisible callback returns false.

Implementation

final bool ignoreBottomInset;