sourceTimeStamp property
Recorded timestamp of the source pointer event that triggered the drag events.
Implementation
final Duration? sourceTimeStamp;
Recorded timestamp of the source pointer event that triggered the drag events.
final Duration? sourceTimeStamp;