ClampingSheetPhysics class
- Inheritance
-
- Object
- SheetPhysics
- ClampingSheetPhysics
- Mixed-in types
Constructors
- ClampingSheetPhysics({SpringDescription spring = _kDefaultSheetSpring})
-
const
Properties
- dragStartDistanceMotionThreshold → double?
-
The minimum amount of pixel distance drags must move by to start motion
the first time or after each time the drag motion stopped.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spring → SpringDescription
-
final
Methods
-
applyPhysicsToOffset(
double delta, SheetMetrics metrics) → double -
inherited
-
computeOverflow(
double delta, SheetMetrics metrics) → double -
inherited
-
createBallisticSimulation(
double velocity, SheetMetrics metrics, SheetSnapGrid snapGrid) → Simulation? -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited