Properties
-
contentBaseline
→ double
-
The minimum distance from the bottom of the viewport
to the bottom of the content area.
no setterinherited
-
contentMargin
→ EdgeInsets
-
The margin by which the content insets the sheet.
no setterinherited
-
contentSize
→ Size
-
The size of the sheet's content.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
size
→ Size
-
The size of the sheet.
no setter
-
viewportPadding
→ EdgeInsets
-
The padding by which the viewport insets the sheet.
no setterinherited
-
viewportSize
→ Size
-
The size of the viewport, which is the rectangle
where the sheet is laid out.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited